.. _httpclient-helper:

************************************************
:mod:`mopidy.httpclient` --- HTTP Client helpers
************************************************

.. automodule:: mopidy.httpclient
    :synopsis: HTTP Client helpers for Mopidy its Extensions.
    :members:
